# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0.dev5
    Generated by: https://openapi-generator.tech
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class CardFulfillmentStatus(str, Enum):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    allowed enum values
    """

    ISSUED = 'ISSUED'
    REISSUED = 'REISSUED'
    ORDERED = 'ORDERED'
    REJECTED = 'REJECTED'
    REORDERED = 'REORDERED'
    SHIPPED = 'SHIPPED'
    DIGITALLY_PRESENTED = 'DIGITALLY_PRESENTED'




# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0.dev5
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictBool, StrictStr
from synctera_client_ng.models.personal_id_type import PersonalIdType

class ResponsePersonalIdWCust(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: StrictStr = Field(..., description="UUID for the personal identifier for subsequent changes and deletion")
    id_type: PersonalIdType = ...
    identifier: StrictStr = Field(..., description="The personal identifier. Format varies by personal identifier type.")
    system_provided: StrictBool = Field(..., description="True if the identifier was provided by the system, e.g. via SSN Prefill.")
    country_code: StrictStr = Field(..., description="The ISO 3166 Alpha-2 country code for the country that issued the personal identifier. ")
    customer_id: StrictStr = Field(..., description="Id of the customer having this personal identifier")
    tenant: StrictStr = Field(..., description="The id of the tenant containing the resource. ")
    __properties = ["id", "id_type", "identifier", "system_provided", "country_code", "customer_id", "tenant"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ResponsePersonalIdWCust:
        """Create an instance of ResponsePersonalIdWCust from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "id",
                            "system_provided",
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ResponsePersonalIdWCust:
        """Create an instance of ResponsePersonalIdWCust from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ResponsePersonalIdWCust.parse_obj(obj)

        _obj = ResponsePersonalIdWCust.parse_obj({
            "id": obj.get("id"),
            "id_type": obj.get("id_type"),
            "identifier": obj.get("identifier"),
            "system_provided": obj.get("system_provided"),
            "country_code": obj.get("country_code"),
            "customer_id": obj.get("customer_id"),
            "tenant": obj.get("tenant")
        })
        return _obj




# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0.dev5
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictStr, validator
from synctera_client_ng.models.accrual_payout_schedule import AccrualPayoutSchedule
from synctera_client_ng.models.calculation_method import CalculationMethod
from synctera_client_ng.models.rate_details import RateDetails

class PatchInterest(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    accrual_payout_schedule: Optional[AccrualPayoutSchedule] = None
    calculation_method: Optional[CalculationMethod] = None
    description: Optional[StrictStr] = Field(None, description="User provided description for the current interest.")
    id: Optional[StrictStr] = Field(None, description="Interest ID")
    product_type: StrictStr = ...
    rates: Optional[List[RateDetails]] = Field(None, description="A list of interest rate. Date intervals between valid_from and valid_to expect to have no overlap. ")
    __properties = ["accrual_payout_schedule", "calculation_method", "description", "id", "product_type", "rates"]

    @validator('product_type')
    def product_type_validate_enum(cls, v):
        if v not in ('INTEREST'):
            raise ValueError("must validate the enum values ('INTEREST')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PatchInterest:
        """Create an instance of PatchInterest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "id",
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in rates (list)
        _items = []
        if self.rates:
            for _item in self.rates:
                if _item:
                    _items.append(_item.to_dict())
            _dict['rates'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PatchInterest:
        """Create an instance of PatchInterest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return PatchInterest.parse_obj(obj)

        _obj = PatchInterest.parse_obj({
            "accrual_payout_schedule": obj.get("accrual_payout_schedule"),
            "calculation_method": obj.get("calculation_method"),
            "description": obj.get("description"),
            "id": obj.get("id"),
            "product_type": obj.get("product_type"),
            "rates": [RateDetails.from_dict(_item) for _item in obj.get("rates")] if obj.get("rates") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0.dev5
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, Dict, List, Optional
from pydantic import BaseModel, Field, StrictStr, validator
from synctera_client_ng.models.vendor_info import VendorInfo

class WatchlistAlert(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    created: Optional[datetime] = Field(None, description="When this alert was created")
    id: Optional[StrictStr] = Field(None, description="Unique identifier for this alert")
    provider_info: Optional[Dict[str, Any]] = Field(None, description="The information provided to Synctera that triggered this alert, as an arbitrary JSON object. Interpretation of this object is up to the client. ")
    provider_subject_id: Optional[StrictStr] = Field(None, description="The id of the provider subject for this alert")
    provider_subscription_id: Optional[StrictStr] = Field(None, description="The id of the provider subscription for this alert")
    provider_watchlist_name: Optional[StrictStr] = Field(None, description="The name of the provider for this alert")
    status: StrictStr = Field(..., description="The status of this alert")
    urls: Optional[List[StrictStr]] = Field(None, description="Where to get more information about this alert (according to our third-party data provider). ")
    vendor_info: Optional[VendorInfo] = None
    __properties = ["created", "id", "provider_info", "provider_subject_id", "provider_subscription_id", "provider_watchlist_name", "status", "urls", "vendor_info"]

    @validator('status')
    def status_validate_enum(cls, v):
        if v not in ('ACTIVE', 'SUPPRESSED'):
            raise ValueError("must validate the enum values ('ACTIVE', 'SUPPRESSED')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> WatchlistAlert:
        """Create an instance of WatchlistAlert from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of vendor_info
        if self.vendor_info:
            _dict['vendor_info'] = self.vendor_info.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> WatchlistAlert:
        """Create an instance of WatchlistAlert from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return WatchlistAlert.parse_obj(obj)

        _obj = WatchlistAlert.parse_obj({
            "created": obj.get("created"),
            "id": obj.get("id"),
            "provider_info": obj.get("provider_info"),
            "provider_subject_id": obj.get("provider_subject_id"),
            "provider_subscription_id": obj.get("provider_subscription_id"),
            "provider_watchlist_name": obj.get("provider_watchlist_name"),
            "status": obj.get("status"),
            "urls": obj.get("urls"),
            "vendor_info": VendorInfo.from_dict(obj.get("vendor_info")) if obj.get("vendor_info") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0.dev5
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import date, datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, validator

class WatchlistSubscription(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    auto_renew: Optional[StrictBool] = Field(None, description="Whether this subscription should automatically renew when the subscription period is over (default: vendor-dependent). ")
    created: Optional[datetime] = Field(None, description="When this subscription was created")
    customer_consent: StrictBool = Field(..., description="Whether this customer has consented to being enrolled for watchlist monitoring ")
    id: Optional[StrictStr] = Field(None, description="Unique identifier for this subscription")
    period_end: Optional[date] = Field(None, description="The date when monitoring of this individual should end.")
    period_start: Optional[date] = Field(None, description="The date when monitoring of this individual should begin (default: today).")
    provider_subscription_id: Optional[StrictStr] = Field(None, description="External provider subscription id")
    status: Optional[StrictStr] = None
    __properties = ["auto_renew", "created", "customer_consent", "id", "period_end", "period_start", "provider_subscription_id", "status"]

    @validator('status')
    def status_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('ACTIVE', 'INACTIVE'):
            raise ValueError("must validate the enum values ('ACTIVE', 'INACTIVE')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> WatchlistSubscription:
        """Create an instance of WatchlistSubscription from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> WatchlistSubscription:
        """Create an instance of WatchlistSubscription from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return WatchlistSubscription.parse_obj(obj)

        _obj = WatchlistSubscription.parse_obj({
            "auto_renew": obj.get("auto_renew"),
            "created": obj.get("created"),
            "customer_consent": obj.get("customer_consent"),
            "id": obj.get("id"),
            "period_end": obj.get("period_end"),
            "period_start": obj.get("period_start"),
            "provider_subscription_id": obj.get("provider_subscription_id"),
            "status": obj.get("status")
        })
        return _obj




# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0.dev5
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import date
from typing import Optional
from pydantic import BaseModel, Field, StrictStr

class StatementSummary(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    account_id: Optional[StrictStr] = Field(None, description="The unique identifier of the account the statement belongs to")
    due_date: Optional[date] = Field(None, description="The limit date when the due amount indicated on the statement should be paid")
    end_date: Optional[date] = Field(None, description="The date indicating the ending of the time interval covered by the statement")
    id: Optional[StrictStr] = Field(None, description="statement ID")
    issue_date: Optional[date] = Field(None, description="The date when the statement has been issued")
    start_date: Optional[date] = Field(None, description="The date indicating the beginning of the time interval covered by the statement")
    __properties = ["account_id", "due_date", "end_date", "id", "issue_date", "start_date"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> StatementSummary:
        """Create an instance of StatementSummary from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "account_id",
                            "due_date",
                            "end_date",
                            "id",
                            "issue_date",
                            "start_date",
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> StatementSummary:
        """Create an instance of StatementSummary from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return StatementSummary.parse_obj(obj)

        _obj = StatementSummary.parse_obj({
            "account_id": obj.get("account_id"),
            "due_date": obj.get("due_date"),
            "end_date": obj.get("end_date"),
            "id": obj.get("id"),
            "issue_date": obj.get("issue_date"),
            "start_date": obj.get("start_date")
        })
        return _obj




# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0.dev5
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr

class Error(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    code: Optional[StrictStr] = Field(None, description="An optional “sneak preview” of our future API v1 error responses. This is provided to give integrators a chance to work with our future error codes. Error codes for the same error may change between v0 and v1.")
    detail: Optional[StrictStr] = Field(None, description="A human-readable string explaining this particular error. ")
    status: Optional[StrictInt] = Field(None, description="the HTTP status code for this response")
    title: Optional[StrictStr] = Field(None, description="A human-readable string for this general category of error, which corresponds 1-to-1 with error types (`title` is the human-readable version of `type`). There can be multiple distinct titles for the same HTTP status code, and the same `title` can result in many different `detail` strings. This field will be removed in API v1. ")
    type: Optional[StrictStr] = Field(None, description="A machine-readable string that identifies the error for programmatic use. This is a URI, i.e. a globally unique identifier. It is _not_ necessarily a URL, so do not expect it to resolve to a web page. You can use this whole string as an error code, or just everything after the last slash. This field will be removed in API v1. ")
    __properties = ["code", "detail", "status", "title", "type"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Error:
        """Create an instance of Error from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Error:
        """Create an instance of Error from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return Error.parse_obj(obj)

        _obj = Error.parse_obj({
            "code": obj.get("code"),
            "detail": obj.get("detail"),
            "status": obj.get("status"),
            "title": obj.get("title"),
            "type": obj.get("type")
        })
        return _obj




# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0.dev5
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import json
import pprint
import re  # noqa: F401

from typing import Any, List, Optional
from pydantic import BaseModel, Field, StrictStr, ValidationError, validator
from synctera_client_ng.models.card_fulfillment_status import CardFulfillmentStatus
from synctera_client_ng.models.card_pin_status import CardPinStatus
from synctera_client_ng.models.card_status import CardStatus
from typing import Any, List
from pydantic import StrictStr, Field

CARDCHANGESTATE_ONE_OF_SCHEMAS = ["CardFulfillmentStatus", "CardPinStatus", "CardStatus"]

class CardChangeState(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    # data type: CardFulfillmentStatus
    oneof_schema_1_validator: Optional[CardFulfillmentStatus] = None
    # data type: CardStatus
    oneof_schema_2_validator: Optional[CardStatus] = None
    # data type: CardPinStatus
    oneof_schema_3_validator: Optional[CardPinStatus] = None
    actual_instance: Any
    one_of_schemas: List[str] = Field(CARDCHANGESTATE_ONE_OF_SCHEMAS, const=True)

    class Config:
        validate_assignment = True

    @validator('actual_instance')
    def actual_instance_must_validate_oneof(cls, v):
        instance = cls()
        error_messages = []
        match = 0
        # validate data type: CardFulfillmentStatus
        if type(v) is not CardFulfillmentStatus:
            error_messages.append(f"Error! Input type `{type(v)}` is not `CardFulfillmentStatus`")
        else:
            match += 1

        # validate data type: CardStatus
        if type(v) is not CardStatus:
            error_messages.append(f"Error! Input type `{type(v)}` is not `CardStatus`")
        else:
            match += 1

        # validate data type: CardPinStatus
        if type(v) is not CardPinStatus:
            error_messages.append(f"Error! Input type `{type(v)}` is not `CardPinStatus`")
        else:
            match += 1

        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when deserializing the JSON string into CardChangeState with oneOf schemas: CardFulfillmentStatus, CardPinStatus, CardStatus. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when deserializing the JSON string into CardChangeState with oneOf schemas: CardFulfillmentStatus, CardPinStatus, CardStatus. Details: " + ", ".join(error_messages))
        else:
            return v

    @classmethod
    def from_dict(cls, obj: dict) -> CardChangeState:
        return cls.from_json(json.dumps(obj))

    @classmethod
    def from_json(cls, json_str: str) -> CardChangeState:
        """Returns the object represented by the json string"""
        instance = cls()
        error_messages = []
        match = 0

        # deserialize data into CardFulfillmentStatus
        try:
            instance.actual_instance = CardFulfillmentStatus.from_json(json_str)
            match += 1
        except ValidationError as e:
            error_messages.append(str(e))
        # deserialize data into CardStatus
        try:
            instance.actual_instance = CardStatus.from_json(json_str)
            match += 1
        except ValidationError as e:
            error_messages.append(str(e))
        # deserialize data into CardPinStatus
        try:
            instance.actual_instance = CardPinStatus.from_json(json_str)
            match += 1
        except ValidationError as e:
            error_messages.append(str(e))

        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when deserializing the JSON string into CardChangeState with oneOf schemas: CardFulfillmentStatus, CardPinStatus, CardStatus. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when deserializing the JSON string into CardChangeState with oneOf schemas: CardFulfillmentStatus, CardPinStatus, CardStatus. Details: " + ", ".join(error_messages))
        else:
            return instance

    def to_json(self) -> str:
        """Returns the JSON representation of the actual instance"""
        if self.actual_instance is not None:
            return self.actual_instance.to_json()
        else:
            return "null"

    def to_dict(self) -> dict:
        """Returns the dict representation of the actual instance"""
        if self.actual_instance is not None:
            return self.actual_instance.to_dict()
        else:
            return dict()

    def to_str(self) -> str:
        """Returns the string representation of the actual instance"""
        return pprint.pformat(self.dict())




# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0.dev5
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr, conint, constr, validator
from synctera_client_ng.models.minimum_payment_partial import MinimumPaymentPartial

class TemplateFieldsLineOfCredit(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    account_type: StrictStr = ...
    bank_country: constr(strict=True) = Field(..., description="Bank country of the account. ISO 3166-1 Alpha-2 or Alpha-3 country code.")
    currency: constr(strict=True) = Field(..., description="Account currency. ISO 4217 alphabetic currency code")
    chargeoff_period: Optional[conint(strict=True, ge=0)] = Field(90, description="The number of days an account can stay delinquent before marking an account as charged-off. ")
    delinquency_period: Optional[conint(strict=True, ge=0)] = Field(30, description="The number of days past the due date to wait for a minimum payment before marking an account as delinquent. ")
    grace_period: Optional[conint(strict=True, ge=0)] = Field(30, description="The number of days past the billing period to allow for payment before it is considered due. This directly infers the due date for a payment. ")
    interest_product_id: Optional[StrictStr] = Field(None, description="An interest account product that the current account associates with. The account product must have its calculation_method set to COMPOUNDED_DAILY. ")
    minimum_payment: MinimumPaymentPartial = ...
    __properties = ["account_type", "bank_country", "currency", "chargeoff_period", "delinquency_period", "grace_period", "interest_product_id", "minimum_payment"]

    @validator('bank_country')
    def bank_country_validate_regular_expression(cls, v):
        if v is None:
            return v
        if not re.match(r"^[A-Z]{2,3}$", v):
            raise ValueError(r"must validate the regular expression /^[A-Z]{2,3}$/")
        return v

    @validator('currency')
    def currency_validate_regular_expression(cls, v):
        if v is None:
            return v
        if not re.match(r"^[A-Z]{3}$", v):
            raise ValueError(r"must validate the regular expression /^[A-Z]{3}$/")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TemplateFieldsLineOfCredit:
        """Create an instance of TemplateFieldsLineOfCredit from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of minimum_payment
        if self.minimum_payment:
            _dict['minimum_payment'] = self.minimum_payment.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TemplateFieldsLineOfCredit:
        """Create an instance of TemplateFieldsLineOfCredit from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return TemplateFieldsLineOfCredit.parse_obj(obj)

        _obj = TemplateFieldsLineOfCredit.parse_obj({
            "account_type": obj.get("account_type"),
            "bank_country": obj.get("bank_country"),
            "currency": obj.get("currency"),
            "chargeoff_period": obj.get("chargeoff_period") if obj.get("chargeoff_period") is not None else 90,
            "delinquency_period": obj.get("delinquency_period") if obj.get("delinquency_period") is not None else 30,
            "grace_period": obj.get("grace_period") if obj.get("grace_period") is not None else 30,
            "interest_product_id": obj.get("interest_product_id"),
            "minimum_payment": MinimumPaymentPartial.from_dict(obj.get("minimum_payment")) if obj.get("minimum_payment") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0.dev5
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from pydantic import Field

from typing import Any, Dict

from synctera_client_ng.models.ach_return_simulation_request import AchReturnSimulationRequest
from synctera_client_ng.models.ach_transaction_simulation_request import AchTransactionSimulationRequest

from synctera_client_ng.api_client import ApiClient
from synctera_client_ng.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class ACHTransactionSimulationsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def ach_return_simulation(self, ach_return_simulation_request : Annotated[AchReturnSimulationRequest, Field(..., description="Incoming ACH return simulation")], **kwargs) -> object:  # noqa: E501
        """Simulate receiving ACH return  # noqa: E501

        Use to simulate receiving ACH return in test environments. Creates an incoming ACH file with a single return entry based on a previously created outgoing transaction. The file gets automatically processed.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.ach_return_simulation(ach_return_simulation_request, async_req=True)
        >>> result = thread.get()

        :param ach_return_simulation_request: Incoming ACH return simulation (required)
        :type ach_return_simulation_request: AchReturnSimulationRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: object
        """
        kwargs['_return_http_data_only'] = True
        return self.ach_return_simulation_with_http_info(ach_return_simulation_request, **kwargs)  # noqa: E501

    @validate_arguments
    def ach_return_simulation_with_http_info(self, ach_return_simulation_request : Annotated[AchReturnSimulationRequest, Field(..., description="Incoming ACH return simulation")], **kwargs):  # noqa: E501
        """Simulate receiving ACH return  # noqa: E501

        Use to simulate receiving ACH return in test environments. Creates an incoming ACH file with a single return entry based on a previously created outgoing transaction. The file gets automatically processed.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.ach_return_simulation_with_http_info(ach_return_simulation_request, async_req=True)
        >>> result = thread.get()

        :param ach_return_simulation_request: Incoming ACH return simulation (required)
        :type ach_return_simulation_request: AchReturnSimulationRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(object, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'ach_return_simulation_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method ach_return_simulation" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None
        if _params['ach_return_simulation_request']:
            _body_params = _params['ach_return_simulation_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/problem+json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '201': "object",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/ach/transaction_simulations/receiving_return', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def ach_transaction_simulation(self, ach_transaction_simulation_request : Annotated[AchTransactionSimulationRequest, Field(..., description="Sent ACH request")], **kwargs) -> object:  # noqa: E501
        """Simulate receiving ACH transaction  # noqa: E501

        Use to simulate receiving ACH transaction in test environments. Creates an incoming ACH file with a single transaction, which gets automatically processed.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.ach_transaction_simulation(ach_transaction_simulation_request, async_req=True)
        >>> result = thread.get()

        :param ach_transaction_simulation_request: Sent ACH request (required)
        :type ach_transaction_simulation_request: AchTransactionSimulationRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: object
        """
        kwargs['_return_http_data_only'] = True
        return self.ach_transaction_simulation_with_http_info(ach_transaction_simulation_request, **kwargs)  # noqa: E501

    @validate_arguments
    def ach_transaction_simulation_with_http_info(self, ach_transaction_simulation_request : Annotated[AchTransactionSimulationRequest, Field(..., description="Sent ACH request")], **kwargs):  # noqa: E501
        """Simulate receiving ACH transaction  # noqa: E501

        Use to simulate receiving ACH transaction in test environments. Creates an incoming ACH file with a single transaction, which gets automatically processed.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.ach_transaction_simulation_with_http_info(ach_transaction_simulation_request, async_req=True)
        >>> result = thread.get()

        :param ach_transaction_simulation_request: Sent ACH request (required)
        :type ach_transaction_simulation_request: AchTransactionSimulationRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(object, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'ach_transaction_simulation_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method ach_transaction_simulation" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None
        if _params['ach_transaction_simulation_request']:
            _body_params = _params['ach_transaction_simulation_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/problem+json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '201': "object",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/ach/transaction_simulations/receiving_transaction', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0.dev5
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr
from synctera_client_ng.models.posted_transaction_data import PostedTransactionData

class PostedTransaction(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    created: datetime = Field(..., description="The creation date of the transaction")
    data: PostedTransactionData = ...
    effective_date: datetime = Field(..., description="The \"effective date\" of a transaction. This may be earlier than posted_date in some cases (for example, a transaction that occurs on a Saturday may not be posted until the following Monday, but would have an effective date of Saturday)")
    id: StrictInt = ...
    idemkey: StrictStr = Field(..., description="The idempotency key used when initially creating this transaction.")
    info_only: StrictBool = Field(..., description="Whether or not this transaction represents a purely informational operation or an actual money movement")
    lead_mode: StrictBool = Field(..., description="Whether or not this transaction was created operating in \"lead ledger\" mode")
    posted_date: datetime = Field(..., description="The date the transaction was posted. This is the date any money is considered to be added or removed from an account.")
    reference_id: Optional[StrictStr] = Field(..., description="An external ID provided by the payment network to represent this transaction. This will always be null for internal transfers.")
    status: StrictStr = ...
    subtype: StrictStr = Field(..., description="The specific transaction type. For example, for `ach`, this may be \"outgoing_debit\".")
    tenant: StrictStr = Field(..., description="The tenant associated with this transaction, in the form \"<bankid>_<partnerid>\"")
    transaction_time: datetime = Field(..., description="The time the transaction occurred.")
    type: StrictStr = Field(..., description="The general type of transaction. For example, \"card\" or \"ach\".")
    updated: datetime = Field(..., description="The date the transaction was last updated")
    uuid: StrictStr = Field(..., description="The unique identifier of the transaction.")
    __properties = ["created", "data", "effective_date", "id", "idemkey", "info_only", "lead_mode", "posted_date", "reference_id", "status", "subtype", "tenant", "transaction_time", "type", "updated", "uuid"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PostedTransaction:
        """Create an instance of PostedTransaction from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of data
        if self.data:
            _dict['data'] = self.data.to_dict()
        # set to None if reference_id (nullable) is None
        if self.reference_id is None:
            _dict['reference_id'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PostedTransaction:
        """Create an instance of PostedTransaction from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return PostedTransaction.parse_obj(obj)

        _obj = PostedTransaction.parse_obj({
            "created": obj.get("created"),
            "data": PostedTransactionData.from_dict(obj.get("data")) if obj.get("data") is not None else None,
            "effective_date": obj.get("effective_date"),
            "id": obj.get("id"),
            "idemkey": obj.get("idemkey"),
            "info_only": obj.get("info_only"),
            "lead_mode": obj.get("lead_mode"),
            "posted_date": obj.get("posted_date"),
            "reference_id": obj.get("reference_id"),
            "status": obj.get("status"),
            "subtype": obj.get("subtype"),
            "tenant": obj.get("tenant"),
            "transaction_time": obj.get("transaction_time"),
            "type": obj.get("type"),
            "updated": obj.get("updated"),
            "uuid": obj.get("uuid")
        })
        return _obj




# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0.dev5
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictStr, conint, validator

from typing import List, Optional

from synctera_client_ng.models.business import Business
from synctera_client_ng.models.business_list import BusinessList
from synctera_client_ng.models.patch_business import PatchBusiness

from synctera_client_ng.api_client import ApiClient
from synctera_client_ng.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class BusinessesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def create_business(self, business : Business, idempotency_key : Annotated[Optional[StrictStr], Field(description="An idempotency key is an arbitrary unique value generated by client to detect subsequent retries of the same request. It is recommended that a UUID or a similar random identifier be used as an idempotency key. A different key must be used for each request, unless it is a retry.")] = None, partner_ownership : Annotated[Optional[StrictStr], Field(description="Return ownership resources for the specified partner. ")] = None, **kwargs) -> Business:  # noqa: E501
        """Create a business  # noqa: E501

        Create a business who may act as a customer or a related business. You can then verify the identity of this customer and associate them with other people and accounts.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_business(business, idempotency_key, partner_ownership, async_req=True)
        >>> result = thread.get()

        :param business: (required)
        :type business: Business
        :param idempotency_key: An idempotency key is an arbitrary unique value generated by client to detect subsequent retries of the same request. It is recommended that a UUID or a similar random identifier be used as an idempotency key. A different key must be used for each request, unless it is a retry.
        :type idempotency_key: str
        :param partner_ownership: Return ownership resources for the specified partner. 
        :type partner_ownership: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Business
        """
        kwargs['_return_http_data_only'] = True
        return self.create_business_with_http_info(business, idempotency_key, partner_ownership, **kwargs)  # noqa: E501

    @validate_arguments
    def create_business_with_http_info(self, business : Business, idempotency_key : Annotated[Optional[StrictStr], Field(description="An idempotency key is an arbitrary unique value generated by client to detect subsequent retries of the same request. It is recommended that a UUID or a similar random identifier be used as an idempotency key. A different key must be used for each request, unless it is a retry.")] = None, partner_ownership : Annotated[Optional[StrictStr], Field(description="Return ownership resources for the specified partner. ")] = None, **kwargs):  # noqa: E501
        """Create a business  # noqa: E501

        Create a business who may act as a customer or a related business. You can then verify the identity of this customer and associate them with other people and accounts.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_business_with_http_info(business, idempotency_key, partner_ownership, async_req=True)
        >>> result = thread.get()

        :param business: (required)
        :type business: Business
        :param idempotency_key: An idempotency key is an arbitrary unique value generated by client to detect subsequent retries of the same request. It is recommended that a UUID or a similar random identifier be used as an idempotency key. A different key must be used for each request, unless it is a retry.
        :type idempotency_key: str
        :param partner_ownership: Return ownership resources for the specified partner. 
        :type partner_ownership: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Business, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'business',
            'idempotency_key',
            'partner_ownership'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_business" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('partner_ownership') is not None:  # noqa: E501
            _query_params.append(('partner_ownership', _params['partner_ownership']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['idempotency_key']:
            _header_params['Idempotency-Key'] = _params['idempotency_key']

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None
        if _params['business']:
            _body_params = _params['business']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/problem+json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '201': "Business",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '409': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/businesses', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_business(self, business_id : Annotated[StrictStr, Field(..., description="Business's unique identifier.")], partner_ownership : Annotated[Optional[StrictStr], Field(description="Return ownership resources for the specified partner. ")] = None, **kwargs) -> Business:  # noqa: E501
        """Get business  # noqa: E501

        Get business by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_business(business_id, partner_ownership, async_req=True)
        >>> result = thread.get()

        :param business_id: Business's unique identifier. (required)
        :type business_id: str
        :param partner_ownership: Return ownership resources for the specified partner. 
        :type partner_ownership: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Business
        """
        kwargs['_return_http_data_only'] = True
        return self.get_business_with_http_info(business_id, partner_ownership, **kwargs)  # noqa: E501

    @validate_arguments
    def get_business_with_http_info(self, business_id : Annotated[StrictStr, Field(..., description="Business's unique identifier.")], partner_ownership : Annotated[Optional[StrictStr], Field(description="Return ownership resources for the specified partner. ")] = None, **kwargs):  # noqa: E501
        """Get business  # noqa: E501

        Get business by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_business_with_http_info(business_id, partner_ownership, async_req=True)
        >>> result = thread.get()

        :param business_id: Business's unique identifier. (required)
        :type business_id: str
        :param partner_ownership: Return ownership resources for the specified partner. 
        :type partner_ownership: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Business, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'business_id',
            'partner_ownership'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_business" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['business_id']:
            _path_params['business_id'] = _params['business_id']

        # process the query parameters
        _query_params = []
        if _params.get('partner_ownership') is not None:  # noqa: E501
            _query_params.append(('partner_ownership', _params['partner_ownership']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/problem+json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "Business",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '404': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/businesses/{business_id}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def list_businesses(self, id : Annotated[Optional[List[StrictStr]], Field(description="Unique identifier for the business. Multiple IDs can be provided as a comma-separated list. ")] = None, entity_name : Optional[StrictStr] = None, phone_number : Optional[StrictStr] = None, status : Optional[StrictStr] = None, tenant : Optional[StrictStr] = None, is_customer : Annotated[Optional[StrictBool], Field(description="If true, show only customers. If false, show non-customer parties.")] = None, sort_by : Annotated[Optional[List[StrictStr]], Field(description="Specifies the sort order for the returned businesses. ")] = None, partner_ownership : Annotated[Optional[StrictStr], Field(description="Return ownership resources for the specified partner. ")] = None, limit : Optional[conint(strict=True, ge=1)] = None, page_token : Optional[StrictStr] = None, **kwargs) -> BusinessList:  # noqa: E501
        """List business  # noqa: E501

        Retrieves paginated list of businesses associated with the authorized requester.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_businesses(id, entity_name, phone_number, status, tenant, is_customer, sort_by, partner_ownership, limit, page_token, async_req=True)
        >>> result = thread.get()

        :param id: Unique identifier for the business. Multiple IDs can be provided as a comma-separated list. 
        :type id: List[str]
        :param entity_name:
        :type entity_name: str
        :param phone_number:
        :type phone_number: str
        :param status:
        :type status: str
        :param tenant:
        :type tenant: str
        :param is_customer: If true, show only customers. If false, show non-customer parties.
        :type is_customer: bool
        :param sort_by: Specifies the sort order for the returned businesses. 
        :type sort_by: List[str]
        :param partner_ownership: Return ownership resources for the specified partner. 
        :type partner_ownership: str
        :param limit:
        :type limit: int
        :param page_token:
        :type page_token: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BusinessList
        """
        kwargs['_return_http_data_only'] = True
        return self.list_businesses_with_http_info(id, entity_name, phone_number, status, tenant, is_customer, sort_by, partner_ownership, limit, page_token, **kwargs)  # noqa: E501

    @validate_arguments
    def list_businesses_with_http_info(self, id : Annotated[Optional[List[StrictStr]], Field(description="Unique identifier for the business. Multiple IDs can be provided as a comma-separated list. ")] = None, entity_name : Optional[StrictStr] = None, phone_number : Optional[StrictStr] = None, status : Optional[StrictStr] = None, tenant : Optional[StrictStr] = None, is_customer : Annotated[Optional[StrictBool], Field(description="If true, show only customers. If false, show non-customer parties.")] = None, sort_by : Annotated[Optional[List[StrictStr]], Field(description="Specifies the sort order for the returned businesses. ")] = None, partner_ownership : Annotated[Optional[StrictStr], Field(description="Return ownership resources for the specified partner. ")] = None, limit : Optional[conint(strict=True, ge=1)] = None, page_token : Optional[StrictStr] = None, **kwargs):  # noqa: E501
        """List business  # noqa: E501

        Retrieves paginated list of businesses associated with the authorized requester.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_businesses_with_http_info(id, entity_name, phone_number, status, tenant, is_customer, sort_by, partner_ownership, limit, page_token, async_req=True)
        >>> result = thread.get()

        :param id: Unique identifier for the business. Multiple IDs can be provided as a comma-separated list. 
        :type id: List[str]
        :param entity_name:
        :type entity_name: str
        :param phone_number:
        :type phone_number: str
        :param status:
        :type status: str
        :param tenant:
        :type tenant: str
        :param is_customer: If true, show only customers. If false, show non-customer parties.
        :type is_customer: bool
        :param sort_by: Specifies the sort order for the returned businesses. 
        :type sort_by: List[str]
        :param partner_ownership: Return ownership resources for the specified partner. 
        :type partner_ownership: str
        :param limit:
        :type limit: int
        :param page_token:
        :type page_token: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(BusinessList, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id',
            'entity_name',
            'phone_number',
            'status',
            'tenant',
            'is_customer',
            'sort_by',
            'partner_ownership',
            'limit',
            'page_token'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_businesses" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('id') is not None:  # noqa: E501
            _query_params.append(('id', _params['id']))
            _collection_formats['id'] = 'csv'
        if _params.get('entity_name') is not None:  # noqa: E501
            _query_params.append(('entity_name', _params['entity_name']))
        if _params.get('phone_number') is not None:  # noqa: E501
            _query_params.append(('phone_number', _params['phone_number']))
        if _params.get('status') is not None:  # noqa: E501
            _query_params.append(('status', _params['status']))
        if _params.get('tenant') is not None:  # noqa: E501
            _query_params.append(('tenant', _params['tenant']))
        if _params.get('is_customer') is not None:  # noqa: E501
            _query_params.append(('is_customer', _params['is_customer']))
        if _params.get('sort_by') is not None:  # noqa: E501
            _query_params.append(('sort_by', _params['sort_by']))
            _collection_formats['sort_by'] = 'csv'
        if _params.get('partner_ownership') is not None:  # noqa: E501
            _query_params.append(('partner_ownership', _params['partner_ownership']))
        if _params.get('limit') is not None:  # noqa: E501
            _query_params.append(('limit', _params['limit']))
        if _params.get('page_token') is not None:  # noqa: E501
            _query_params.append(('page_token', _params['page_token']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/problem+json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "BusinessList",
            '401': "Error",
            '403': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/businesses', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def update_business(self, business_id : Annotated[StrictStr, Field(..., description="Business's unique identifier.")], patch_business : PatchBusiness, idempotency_key : Annotated[Optional[StrictStr], Field(description="An idempotency key is an arbitrary unique value generated by client to detect subsequent retries of the same request. It is recommended that a UUID or a similar random identifier be used as an idempotency key. A different key must be used for each request, unless it is a retry.")] = None, partner_ownership : Annotated[Optional[StrictStr], Field(description="Return ownership resources for the specified partner. ")] = None, **kwargs) -> Business:  # noqa: E501
        """Patch business  # noqa: E501

        Update business by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_business(business_id, patch_business, idempotency_key, partner_ownership, async_req=True)
        >>> result = thread.get()

        :param business_id: Business's unique identifier. (required)
        :type business_id: str
        :param patch_business: (required)
        :type patch_business: PatchBusiness
        :param idempotency_key: An idempotency key is an arbitrary unique value generated by client to detect subsequent retries of the same request. It is recommended that a UUID or a similar random identifier be used as an idempotency key. A different key must be used for each request, unless it is a retry.
        :type idempotency_key: str
        :param partner_ownership: Return ownership resources for the specified partner. 
        :type partner_ownership: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Business
        """
        kwargs['_return_http_data_only'] = True
        return self.update_business_with_http_info(business_id, patch_business, idempotency_key, partner_ownership, **kwargs)  # noqa: E501

    @validate_arguments
    def update_business_with_http_info(self, business_id : Annotated[StrictStr, Field(..., description="Business's unique identifier.")], patch_business : PatchBusiness, idempotency_key : Annotated[Optional[StrictStr], Field(description="An idempotency key is an arbitrary unique value generated by client to detect subsequent retries of the same request. It is recommended that a UUID or a similar random identifier be used as an idempotency key. A different key must be used for each request, unless it is a retry.")] = None, partner_ownership : Annotated[Optional[StrictStr], Field(description="Return ownership resources for the specified partner. ")] = None, **kwargs):  # noqa: E501
        """Patch business  # noqa: E501

        Update business by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_business_with_http_info(business_id, patch_business, idempotency_key, partner_ownership, async_req=True)
        >>> result = thread.get()

        :param business_id: Business's unique identifier. (required)
        :type business_id: str
        :param patch_business: (required)
        :type patch_business: PatchBusiness
        :param idempotency_key: An idempotency key is an arbitrary unique value generated by client to detect subsequent retries of the same request. It is recommended that a UUID or a similar random identifier be used as an idempotency key. A different key must be used for each request, unless it is a retry.
        :type idempotency_key: str
        :param partner_ownership: Return ownership resources for the specified partner. 
        :type partner_ownership: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Business, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'business_id',
            'patch_business',
            'idempotency_key',
            'partner_ownership'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_business" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['business_id']:
            _path_params['business_id'] = _params['business_id']

        # process the query parameters
        _query_params = []
        if _params.get('partner_ownership') is not None:  # noqa: E501
            _query_params.append(('partner_ownership', _params['partner_ownership']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['idempotency_key']:
            _header_params['Idempotency-Key'] = _params['idempotency_key']

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None
        if _params['patch_business']:
            _body_params = _params['patch_business']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/problem+json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "Business",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '404': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/businesses/{business_id}', 'PATCH',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0.dev5
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field
from synctera_client_ng.models.disclosure import Disclosure

class DisclosureListAllOf(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    disclosures: List[Disclosure] = Field(..., description="Array of disclosures.")
    __properties = ["disclosures"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DisclosureListAllOf:
        """Create an instance of DisclosureListAllOf from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in disclosures (list)
        _items = []
        if self.disclosures:
            for _item in self.disclosures:
                if _item:
                    _items.append(_item.to_dict())
            _dict['disclosures'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DisclosureListAllOf:
        """Create an instance of DisclosureListAllOf from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return DisclosureListAllOf.parse_obj(obj)

        _obj = DisclosureListAllOf.parse_obj({
            "disclosures": [Disclosure.from_dict(_item) for _item in obj.get("disclosures")] if obj.get("disclosures") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0.dev5
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from datetime import date

from pydantic import Field, StrictStr, conint

from typing import Optional

from synctera_client_ng.models.cash_pickup import CashPickup
from synctera_client_ng.models.cash_pickup_list import CashPickupList
from synctera_client_ng.models.cash_pickup_patch_request import CashPickupPatchRequest
from synctera_client_ng.models.cash_pickup_post_request import CashPickupPostRequest
from synctera_client_ng.models.cash_pickup_status import CashPickupStatus

from synctera_client_ng.api_client import ApiClient
from synctera_client_ng.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class CashPickupsAlphaApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def create_cash_pickup(self, cash_pickup_post_request : Annotated[CashPickupPostRequest, Field(..., description="cash pickup to create")], **kwargs) -> CashPickup:  # noqa: E501
        """Create a cash pickup  # noqa: E501

        Create a cash pickup  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_cash_pickup(cash_pickup_post_request, async_req=True)
        >>> result = thread.get()

        :param cash_pickup_post_request: cash pickup to create (required)
        :type cash_pickup_post_request: CashPickupPostRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CashPickup
        """
        kwargs['_return_http_data_only'] = True
        return self.create_cash_pickup_with_http_info(cash_pickup_post_request, **kwargs)  # noqa: E501

    @validate_arguments
    def create_cash_pickup_with_http_info(self, cash_pickup_post_request : Annotated[CashPickupPostRequest, Field(..., description="cash pickup to create")], **kwargs):  # noqa: E501
        """Create a cash pickup  # noqa: E501

        Create a cash pickup  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_cash_pickup_with_http_info(cash_pickup_post_request, async_req=True)
        >>> result = thread.get()

        :param cash_pickup_post_request: cash pickup to create (required)
        :type cash_pickup_post_request: CashPickupPostRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CashPickup, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'cash_pickup_post_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_cash_pickup" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None
        if _params['cash_pickup_post_request']:
            _body_params = _params['cash_pickup_post_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/problem+json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '201': "CashPickup",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '409': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/cash_pickups', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_cash_pickup(self, cash_pickup_id : Annotated[StrictStr, Field(..., description="The unique identifier of a cash pickup")], **kwargs) -> CashPickup:  # noqa: E501
        """Get a cash pickup  # noqa: E501

        Get a cash pickup  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_cash_pickup(cash_pickup_id, async_req=True)
        >>> result = thread.get()

        :param cash_pickup_id: The unique identifier of a cash pickup (required)
        :type cash_pickup_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CashPickup
        """
        kwargs['_return_http_data_only'] = True
        return self.get_cash_pickup_with_http_info(cash_pickup_id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_cash_pickup_with_http_info(self, cash_pickup_id : Annotated[StrictStr, Field(..., description="The unique identifier of a cash pickup")], **kwargs):  # noqa: E501
        """Get a cash pickup  # noqa: E501

        Get a cash pickup  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_cash_pickup_with_http_info(cash_pickup_id, async_req=True)
        >>> result = thread.get()

        :param cash_pickup_id: The unique identifier of a cash pickup (required)
        :type cash_pickup_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CashPickup, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'cash_pickup_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_cash_pickup" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['cash_pickup_id']:
            _path_params['cash_pickup_id'] = _params['cash_pickup_id']

        # process the query parameters
        _query_params = []

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/problem+json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "CashPickup",
            '401': "Error",
            '403': "Error",
            '404': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/cash_pickups/{cash_pickup_id}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def list_cash_pickups(self, account_id : Annotated[Optional[StrictStr], Field(description="the account id")] = None, from_date : Annotated[Optional[date], Field(description="the biginning of the time window to search for")] = None, to_date : Annotated[Optional[date], Field(description="the ending of the time window to search for")] = None, status : Annotated[Optional[CashPickupStatus], Field(description="the status of the request")] = None, employee_customer_id : Annotated[Optional[StrictStr], Field(description="the Id of the customer who created the cash pickup request")] = None, business_id : Annotated[Optional[StrictStr], Field(description="the Id of bussiness to search for")] = None, limit : Optional[conint(strict=True, ge=1)] = None, page_token : Optional[StrictStr] = None, **kwargs) -> CashPickupList:  # noqa: E501
        """List cash pickups  # noqa: E501

        Get paginated list of cash pickups  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_cash_pickups(account_id, from_date, to_date, status, employee_customer_id, business_id, limit, page_token, async_req=True)
        >>> result = thread.get()

        :param account_id: the account id
        :type account_id: str
        :param from_date: the biginning of the time window to search for
        :type from_date: date
        :param to_date: the ending of the time window to search for
        :type to_date: date
        :param status: the status of the request
        :type status: CashPickupStatus
        :param employee_customer_id: the Id of the customer who created the cash pickup request
        :type employee_customer_id: str
        :param business_id: the Id of bussiness to search for
        :type business_id: str
        :param limit:
        :type limit: int
        :param page_token:
        :type page_token: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CashPickupList
        """
        kwargs['_return_http_data_only'] = True
        return self.list_cash_pickups_with_http_info(account_id, from_date, to_date, status, employee_customer_id, business_id, limit, page_token, **kwargs)  # noqa: E501

    @validate_arguments
    def list_cash_pickups_with_http_info(self, account_id : Annotated[Optional[StrictStr], Field(description="the account id")] = None, from_date : Annotated[Optional[date], Field(description="the biginning of the time window to search for")] = None, to_date : Annotated[Optional[date], Field(description="the ending of the time window to search for")] = None, status : Annotated[Optional[CashPickupStatus], Field(description="the status of the request")] = None, employee_customer_id : Annotated[Optional[StrictStr], Field(description="the Id of the customer who created the cash pickup request")] = None, business_id : Annotated[Optional[StrictStr], Field(description="the Id of bussiness to search for")] = None, limit : Optional[conint(strict=True, ge=1)] = None, page_token : Optional[StrictStr] = None, **kwargs):  # noqa: E501
        """List cash pickups  # noqa: E501

        Get paginated list of cash pickups  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_cash_pickups_with_http_info(account_id, from_date, to_date, status, employee_customer_id, business_id, limit, page_token, async_req=True)
        >>> result = thread.get()

        :param account_id: the account id
        :type account_id: str
        :param from_date: the biginning of the time window to search for
        :type from_date: date
        :param to_date: the ending of the time window to search for
        :type to_date: date
        :param status: the status of the request
        :type status: CashPickupStatus
        :param employee_customer_id: the Id of the customer who created the cash pickup request
        :type employee_customer_id: str
        :param business_id: the Id of bussiness to search for
        :type business_id: str
        :param limit:
        :type limit: int
        :param page_token:
        :type page_token: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CashPickupList, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'account_id',
            'from_date',
            'to_date',
            'status',
            'employee_customer_id',
            'business_id',
            'limit',
            'page_token'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_cash_pickups" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('account_id') is not None:  # noqa: E501
            _query_params.append(('account_id', _params['account_id']))
        if _params.get('from_date') is not None:  # noqa: E501
            _query_params.append(('from_date', _params['from_date']))
        if _params.get('to_date') is not None:  # noqa: E501
            _query_params.append(('to_date', _params['to_date']))
        if _params.get('status') is not None:  # noqa: E501
            _query_params.append(('status', _params['status']))
        if _params.get('employee_customer_id') is not None:  # noqa: E501
            _query_params.append(('employee_customer_id', _params['employee_customer_id']))
        if _params.get('business_id') is not None:  # noqa: E501
            _query_params.append(('business_id', _params['business_id']))
        if _params.get('limit') is not None:  # noqa: E501
            _query_params.append(('limit', _params['limit']))
        if _params.get('page_token') is not None:  # noqa: E501
            _query_params.append(('page_token', _params['page_token']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/problem+json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "CashPickupList",
            '401': "Error",
            '403': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/cash_pickups', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def patch_cash_pickup(self, cash_pickup_id : Annotated[StrictStr, Field(..., description="The unique identifier of a cash pickup")], cash_pickup_patch_request : Annotated[CashPickupPatchRequest, Field(..., description="cash pickup to update")], **kwargs) -> CashPickup:  # noqa: E501
        """Update a cash pickup  # noqa: E501

        Update a cash pickup  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.patch_cash_pickup(cash_pickup_id, cash_pickup_patch_request, async_req=True)
        >>> result = thread.get()

        :param cash_pickup_id: The unique identifier of a cash pickup (required)
        :type cash_pickup_id: str
        :param cash_pickup_patch_request: cash pickup to update (required)
        :type cash_pickup_patch_request: CashPickupPatchRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CashPickup
        """
        kwargs['_return_http_data_only'] = True
        return self.patch_cash_pickup_with_http_info(cash_pickup_id, cash_pickup_patch_request, **kwargs)  # noqa: E501

    @validate_arguments
    def patch_cash_pickup_with_http_info(self, cash_pickup_id : Annotated[StrictStr, Field(..., description="The unique identifier of a cash pickup")], cash_pickup_patch_request : Annotated[CashPickupPatchRequest, Field(..., description="cash pickup to update")], **kwargs):  # noqa: E501
        """Update a cash pickup  # noqa: E501

        Update a cash pickup  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.patch_cash_pickup_with_http_info(cash_pickup_id, cash_pickup_patch_request, async_req=True)
        >>> result = thread.get()

        :param cash_pickup_id: The unique identifier of a cash pickup (required)
        :type cash_pickup_id: str
        :param cash_pickup_patch_request: cash pickup to update (required)
        :type cash_pickup_patch_request: CashPickupPatchRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CashPickup, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'cash_pickup_id',
            'cash_pickup_patch_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method patch_cash_pickup" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['cash_pickup_id']:
            _path_params['cash_pickup_id'] = _params['cash_pickup_id']

        # process the query parameters
        _query_params = []

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None
        if _params['cash_pickup_patch_request']:
            _body_params = _params['cash_pickup_patch_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/problem+json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "CashPickup",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '404': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/cash_pickups/{cash_pickup_id}', 'PATCH',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))
